@@ -1,10 +1,10 @@
-;;; doric-marble-theme.el --- Minimalist light theme -*- lexical-binding:t -*-
+;;; doric-marble-theme.el --- Minimalist theme with light grey background and rocky hues -*- lexical-binding:t -*-
 
-;; Copyright (C) 2025  Free Software Foundation, Inc.
+;; Copyright (C) 2025-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
-;; URL: https://github.com/protesilaos/ef-themes
+;; URL: https://github.com/protesilaos/doric-themes
 ;; Keywords: faces, theme, accessibility
 
 ;; This file is NOT part of GNU Emacs.
@@ -67,14 +67,14 @@
       (fg-cyan "#005355")
 
       (bg-red "#eac0bf")
-      (bg-green "#c0e2c4")
+      (bg-green "#bde0c2")
       (bg-yellow "#f0f0b0")
       (bg-blue "#c4cfe8")
       (bg-magenta "#eec2e6")
       (bg-cyan "#c1ebe4"))
   "Palette of `doric-marble' theme.")
 
-  (doric-themes-define-theme doric-marble light))
+  (doric-themes-define-theme doric-marble light "Minimalist theme with light grey background and rocky hues"))
 
 (provide 'doric-marble-theme)
 ;;; doric-marble-theme.el ends here
